16.136. cdist-type__rbenv(7) — cdist 6.9.4 documentation

# 16.136. cdist-type__rbenv(7)

## 16.136.1. NAME

cdist-type__rbenv - Manage rbenv installation

## 16.136.2. DESCRIPTION

This cdist type allows you to manage rbenv installations. It also installs ruby-build.

## 16.136.3. OPTIONAL PARAMETERS

state

  Either "present" or "absent", defaults to "present"

owner

  Which user should own the rbenv installation, defaults to root

## 16.136.4. EXAMPLES

    # Install rbenv including ruby-build for nico
    __rbenv /home/nico

    # Install rbenv including ruby-build for nico
    __rbenv /home/nico --owner nico

    # Bastian does not need rbenv anymore, he began to code C99
    __rbenv /home/bastian --state absent

## 16.136.5. AUTHORS

Nico Schottelius <nico-cdist--@--schottelius.org>

## 16.136.6. COPYING

Copyright (C) 2012-2014 Nico Schottelius. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.